
# Slot: type




URI: [ks:EmploymentEvent_type](https://w3id.org/linkml/tests/kitchen_sink/EmploymentEvent_type)


## Domain and Range

[EmploymentEvent](EmploymentEvent.md) &#8594;  <sub>0..1</sub> [EmploymentEventType](EmploymentEventType.md)

## Parents

 *  is_a: [type](type.md)

## Children


## Used by

 * [EmploymentEvent](EmploymentEvent.md)
